/*
 * Copyright (c) 1998-2008 TeamDev Ltd. All Rights Reserved.
 * Use is subject to license terms.
 */
package com.teamdev.xpcom.mozilla.demo.components;

import java.awt.BorderLayout;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.SwingUtilities;

import com.teamdev.jxbrowser.WebBrowser;
import com.teamdev.jxbrowser.WebBrowserFactory;
import com.teamdev.jxbrowser.event.LocationEvent;
import com.teamdev.jxbrowser.event.RequestAdapter;
import com.teamdev.jxbrowser.event.StateEvent;

public class SourceFrame extends JFrame {

	private static final long serialVersionUID = -5536641952287664166L;

	public SourceFrame(WebBrowser webBrowser, int xLocation, int yLocation) {
		super();
		setTitle("Source of: " + webBrowser.getLocationURL()
				+ " - JxBrowser Demo");
		setIconImage(new ImageIcon(getClass().getResource(
				"res/jxbrowser16x16.png")).getImage());
		setLocation(xLocation, yLocation);

		final WebBrowser sourceBrowser = WebBrowserFactory.getInstance()
				.createBrowser();

		sourceBrowser.addRequestListener(new RequestAdapter() {

			final RequestAdapter thisAdapter = this;

			boolean location_changed = false;

			@Override
			public void locationChanged(LocationEvent event) {
				if (!event.getLocation().equals("about:blank")) {
					location_changed = true;
				}
			}

			@Override
			public void stateChanged(StateEvent event) {
				if (event.isLoadingCompleted() && location_changed) 
				{
					SwingUtilities.invokeLater(new Runnable() {

						public void run() {
							sourceBrowser.stop();
							//sourceBrowser.deactivate();
							sourceBrowser.displayAsSource(true);
							sourceBrowser.removeRequestListener(thisAdapter);
							setVisible(true);
						}
					});
				}
			}
		});

		String content = webBrowser.getDocumentContent("text/html");
		sourceBrowser.setContent(content, "text/html");

		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(sourceBrowser.getComponent(), BorderLayout.CENTER);
		pack();

		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				closeWindow();
			}
		});

		addKeyListener(new KeyListener() {

			public void keyPressed(KeyEvent e) {
				if (e.getKeyCode() == KeyEvent.VK_ESCAPE) {
					closeWindow();
				}
			}

			public void keyReleased(KeyEvent e) {
				if (e.getKeyCode() == KeyEvent.VK_ESCAPE) {
					closeWindow();
				}
			}

			public void keyTyped(KeyEvent e) {
				if (e.getKeyCode() == KeyEvent.VK_ESCAPE) {
					closeWindow();
				}
			}

		});

		setSize(DEFAULT_WIDTH, DEFAULT_HEIGHT);
	}

	private void closeWindow() {
		dispose();
	}

	private static final int DEFAULT_WIDTH = 600;

	private static final int DEFAULT_HEIGHT = 600;
}
